@@ -56,11 +56,20 @@ class Cropping(object):
 
 
 class Resampling(object):
-    def __init__(self, anisotropy_axis_index = None, target_spacing = [1.0, 1.0, 1.0], random = False):
-        self.device = None
+    def __init__(self, anisotropy_axis_index = None, target_spacing = [1.0, 1.0, 1.0], random = False, device = None):
+        self.device = device
         self.anisotropy_axis_index = anisotropy_axis_index
+        target_spacing = self.new_spacing(target_spacing)
         self.target_spacing = np.array(target_spacing)
         self.random = random
+    
+    def new_spacing(self, spacing):
+        new_spacing = np.zeros(3)
+        new_spacing[0] = spacing[2]
+        new_spacing[1] = spacing[0]
+        new_spacing[2] = spacing[1]
+        return new_spacing
+    
 
     def __call__(self, data, info_data, mode = 'x'):
         if isinstance(data, np.ndarray):
@@ -69,6 +78,7 @@ class Resampling(object):
             data = data.to(self.device)
 
         original_spacing = info_data['spacing']
+        original_spacing = self.new_spacing(original_spacing)
         if self.random:
             self.target_spacing = original_spacing * np.random.uniform(0.20, 5.0, size = np.array(original_spacing).shape)
         new_shape = list((original_spacing[::-1]/self.target_spacing[::-1] * np.array([data.shape[-3], data.shape[-2], data.shape[-1]])).astype(int))
