@@ -5,7 +5,8 @@ def deep_supervision_visualization(output, target):
     # output shape = (batch size, deepsupervision size, channel size, x, y, z)
     ds = output.shape[1]
     n_cls = output.shape[2]
-    center = output.shape[3] // 2
+    if torch.where(target != 0):
+        center = torch.where(target != 0)[1]
     for d_i in range(ds):
         print("deepsupervision layer", d_i + 1)
         plt.figure(figsize=(3 * (ds), 3*(n_cls+2)))
